:hide-toc:

***********
python-uhid
***********

A pure Python typed implementation of the Linux UHID API. This allows you to
create virtual HID devices. It is very useful to emulate devices for testing or
similar tasks.

See the `official UHID documentation`_.

.. toctree::
   :hidden:

   api

   Source Code <https://github.com/FFY00/python-uhid/>
   Issue Tracker <https://github.com/FFY00/python-uhid/issues>

.. _official UHID documentation: https://www.kernel.org/doc/Documentation/hid/uhid.txt
